@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2009, 2010 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2009, 2010, 2012 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -30,10 +30,10 @@
 
 import sys
 
-_p_linux = sys.platform == 'linux2'
+_p_linux = sys.platform.startswith('linux')
 
 if not _p_linux:
-    raise NotImplementedError
+    raise NotImplementedError('the %r platform is not supported' % sys.platform)
 
 if _p_linux:
 
